@@ -54,14 +54,11 @@ def gen_colored_noise(alpha=1, nt=100, f0=None, m=None, seed=None):
     return t, v
     
 def load_data():
-    # note: JEG swapped the two choices on 03/07/2022 to get through PaleoHack 3. 
-    # Awaits fixing of jsonutils (issue 209)
     try:
-        d = pyleo.utils.jsonutils.json_to_Scalogram('../../example_data/scal_signif_benthic.json')
-    except:
         url = 'https://raw.githubusercontent.com/LinkedEarth/Pyleoclim_util/Development/example_data/scal_signif_benthic.json'
-        response = urlopen(url)
-        d = json.loads(response.read())
+        d = pyleo.utils.jsonutils.json_to_Scalogram(url)
+    except:
+        d = pyleo.utils.jsonutils.json_to_Scalogram('../../example_data/scal_signif_benthic.json')
     return d
 
 # Tests below
@@ -136,7 +133,7 @@ class TestUiSeriesSpectral:
     [parametrizing tests](https://docs.pytest.org/en/stable/example/parametrize.html).
     '''
 
-    @pytest.mark.parametrize('spec_method', ['wwz', 'mtm', 'lomb_scargle', 'welch', 'periodogram'])
+    @pytest.mark.parametrize('spec_method', ['wwz', 'mtm', 'lomb_scargle', 'welch', 'periodogram','cwt'])
     def test_spectral_t0(self, spec_method, eps=0.5):
         ''' Test Series.spectral() with available methods using default arguments
 
@@ -176,8 +173,8 @@ class TestUiSeriesSpectral:
         beta = psd.beta_est().beta_est_res['beta']
         assert np.abs(beta-alpha) < eps
 
-    @pytest.mark.parametrize('nv', [10, 20, 30])
-    def test_spectral_t3(self, nv, eps=0.3):
+    @pytest.mark.parametrize('dj', [0.25, 0.5, 1])
+    def test_spectral_t3(self, dj, eps=0.3):
         ''' Test Series.spectral() with MTM using `freq_method='scale'` with different values for its keyword argument `nv`
 
         We will estimate the scaling slope of an ideal colored noise to make sure the result is reasonable.
@@ -185,7 +182,7 @@ class TestUiSeriesSpectral:
         alpha = 1
         t, v = gen_colored_noise(nt=500, alpha=alpha)
         ts = pyleo.Series(time=t, value=v)
-        psd = ts.spectral(method='mtm', freq_method='scale', freq_kwargs={'nv': nv})
+        psd = ts.spectral(method='mtm', freq_method='scale', freq_kwargs={'dj': dj})
         beta = psd.beta_est().beta_est_res['beta']
         assert np.abs(beta-alpha) < eps
 
@@ -236,15 +233,16 @@ class TestUiSeriesSpectral:
         psd = ts.spectral(method=spec_method)
         beta = psd.beta_est().beta_est_res['beta']
         assert np.abs(beta-alpha) < eps
-        
-    def test_spectral_t7(self):
+    
+    @pytest.mark.parametrize('spec_method', ['wwz','cwt'])
+    def test_spectral_t7(self, spec_method,):
         '''Test the spectral significance testing with pre-generated scalogram objects
         '''
         
         ts = pyleo.gen_ts(model='colored_noise')
-        scal = ts.wavelet()
+        scal = ts.wavelet(method=spec_method)
         signif = scal.signif_test(number=2,export_scal = True)
-        sig_psd = ts.spectral(method='wwz',scalogram=scal)
+        sig_psd = ts.spectral(method=spec_method,scalogram=scal)
         sig_psd.signif_test(number=2,scalogram=signif).plot()
 
 class TestUiSeriesBin:
@@ -487,7 +485,7 @@ class TestUiSeriesSummaryPlot:
         Passing just a pre generated psd.
         '''
         scal = load_data()
-        ts = scal.__dict__['timeseries']
+        ts = scal.timeseries
         fig, ax = ts.summary_plot()
     
         plt.close(fig)  
@@ -499,7 +497,7 @@ class TestUiSeriesSummaryPlot:
         Passing just a pre generated psd.
         '''
         scal = load_data()
-        ts = scal.__dict__['timeseries']
+        ts = scal.timeseries
         fig, ax = ts.summary_plot(
             scalogram = scal
         )
@@ -513,7 +511,7 @@ class TestUiSeriesSummaryPlot:
         Passing just a pre generated psd.
         '''
         scal = load_data()
-        ts = scal.__dict__['timeseries']
+        ts = scal.timeseries
         psd = ts.spectral(scalogram=scal)
         fig, ax = ts.summary_plot(
             psd = psd
@@ -528,7 +526,7 @@ class TestUiSeriesSummaryPlot:
         Passing just a pre generated psd.
         '''
         scal = load_data()
-        ts = scal.__dict__['timeseries']
+        ts = scal.timeseries
         fig, ax = ts.summary_plot(
             scalogram = scal, psd_method='lomb_scargle'
         )
@@ -788,8 +786,7 @@ class TestUISeriesWavelet():
     ''' Test the wavelet functionalities
     '''
 
-    #@pytest.mark.parametrize('wave_method',['wwz','cwt'])
-    @pytest.mark.parametrize('wave_method',['wwz'])
+    @pytest.mark.parametrize('wave_method',['wwz','cwt'])
     def test_wave_t0(self, wave_method):
         ''' Test Series.wavelet() with available methods using default arguments
         '''
@@ -798,8 +795,7 @@ class TestUISeriesWavelet():
         ts = pyleo.Series(time=t, value=v)
         scal = ts.wavelet(method=wave_method)
 
-    #@pytest.mark.parametrize('wave_method',['wwz','cwt'])
-    @pytest.mark.parametrize('wave_method',['wwz'])
+    @pytest.mark.parametrize('wave_method',['wwz','cwt'])
     def test_wave_t1(self,wave_method):
         '''Test Series.spectral() with WWZ/cwt with specified frequency vector passed via `settings`
         '''
