@@ -13,7 +13,7 @@ __all__ = [
     'bin',
     'interp',
     'gkernel',
-    'grid_properties',
+    'increments',
     'standardize',
     'ts2segments',
     'annualize',
@@ -193,7 +193,7 @@ def gkernel(t,y, h = 3.0, step=None,start=None,stop=None, step_style = 'max'):
         The interpolation step. Default is max spacing between consecutive points.
    
     step_style : 'string'
-            step style to be applied from `grid_properties` [default = 'max']
+            step style to be applied from `increments` [default = 'max']
     
     start : float
         where/when to start the interpolation. Default is min(t).
@@ -224,7 +224,7 @@ def gkernel(t,y, h = 3.0, step=None,start=None,stop=None, step_style = 'max'):
         
     # get the interpolation step if not provided
     if step is None:
-        _, _, step = grid_properties(np.asarray(t), step_style = step_style)
+        _, _, step = increments(np.asarray(t), step_style = step_style)
         # Get the start and end point if not given
     if start is None:
         start = np.nanmin(np.asarray(t))
@@ -254,8 +254,8 @@ def gkernel(t,y, h = 3.0, step=None,start=None,stop=None, step_style = 'max'):
     return tc, yc
 
 
-def grid_properties(x,step_style='median'):
-    ''' Establishes the grid properties of a numerical array:
+def increments(x,step_style='median'):
+    ''' Establishes the increments of a numerical array:
         start, stop, and representative step.
 
     Parameters
@@ -331,7 +331,7 @@ def interp(x,y, interp_type='linear', step=None,start=None,stop=None, step_style
 
     # get the interpolation step if not available
     if step is None:
-        _, _, step = grid_properties(np.asarray(x), step_style = step_style)
+        _, _, step = increments(np.asarray(x), step_style = step_style)
 
         # Get the start and end point if not given
     if start is None:
@@ -352,86 +352,86 @@ def interp(x,y, interp_type='linear', step=None,start=None,stop=None, step_style
     return xi, yi
 
 
-def on_common_axis(x1, y1, x2, y2, method = 'interpolation', step=None, start=None, stop=None):
-    """Places two timeseries on a common axis
+# def on_common_axis(x1, y1, x2, y2, method = 'interpolation', step=None, start=None, stop=None):
+#     """Places two timeseries on a common axis
 
-    Note this function assumes that the time representation and units are the same (e.g., BP vs CE)
+#     Note this function assumes that the time representation and units are the same (e.g., BP vs CE)
 
-    Parameters
-    ----------
-    x1 : array
-        x-axis values of the first timeseries
-    y1 : array
-        y-axis values of the first timeseries
-    x2 : array
-        x-axis values of the second timeseries
-    y2 : array
-        y-axis values of the second timeseries
-    method : str
-        Which method to use to get the timeseries on the same x axis.
-        Valid entries: 'interpolation' (default, linear interpolation),
-        'bin', 'None'. 'None' only cuts the timeseries to the common
-        period but does not attempt to generate a common time axis
-    step : float
-        The interpolation step. Default is mean resolution
-        of lowest resolution series
-    start : float
-        where/when to start. Default is the maximum of the minima of
-        the two timeseries
-    stop : float
-        Where/when to stop. Default is the minimum of the maxima of
-        the two timeseries
+#     Parameters
+#     ----------
+#     x1 : array
+#         x-axis values of the first timeseries
+#     y1 : array
+#         y-axis values of the first timeseries
+#     x2 : array
+#         x-axis values of the second timeseries
+#     y2 : array
+#         y-axis values of the second timeseries
+#     method : str
+#         Which method to use to get the timeseries on the same x axis.
+#         Valid entries: 'interpolation' (default, linear interpolation),
+#         'bin', 'None'. 'None' only cuts the timeseries to the common
+#         period but does not attempt to generate a common time axis
+#     step : float
+#         The interpolation step. Default is mean resolution
+#         of lowest resolution series
+#     start : float
+#         where/when to start. Default is the maximum of the minima of
+#         the two timeseries
+#     stop : float
+#         Where/when to stop. Default is the minimum of the maxima of
+#         the two timeseries
 
-    Returns
-    -------
+#     Returns
+#     -------
 
-    xi1, xi2 : array
-        The interpolated x-axis
-    interp_values1, interp_values2 : array
-        the interpolated y-values
-    """
-    # make sure that x1, y1, x2, y2 are numpy arrays
-    x1 = np.array(x1, dtype='float64')
-    y1 = np.array(y1, dtype='float64')
-    x2 = np.array(x2, dtype='float64')
-    y2 = np.array(y2, dtype='float64')
+#     xi1, xi2 : array
+#         The interpolated x-axis
+#     interp_values1, interp_values2 : array
+#         the interpolated y-values
+#     """
+#     # make sure that x1, y1, x2, y2 are numpy arrays
+#     x1 = np.array(x1, dtype='float64')
+#     y1 = np.array(y1, dtype='float64')
+#     x2 = np.array(x2, dtype='float64')
+#     y2 = np.array(y2, dtype='float64')
 
-    # Find the mean/max x-axis is not provided
-    if start is None:
-        start = np.nanmax([np.nanmin(x1), np.nanmin(x2)])
-    if stop is None:
-        stop = np.nanmin([np.nanmax(x1), np.nanmax(x2)])
+#     # Find the mean/max x-axis is not provided
+#     if start is None:
+#         start = np.nanmax([np.nanmin(x1), np.nanmin(x2)])
+#     if stop is None:
+#         stop = np.nanmin([np.nanmax(x1), np.nanmax(x2)])
 
-    # Get the interp_step
-    if step is None:
-        step = np.nanmin([np.nanmean(np.diff(x1)), np.nanmean(np.diff(x2))])
+#     # Get the interp_step
+#     if step is None:
+#         step = np.nanmin([np.nanmean(np.diff(x1)), np.nanmean(np.diff(x2))])
 
-    if method == 'interpolation':
-    # perform the interpolation
-        xi1, interp_values1 = interp(x1, y1, step=step, start=start,
-                                stop=stop)
-        xi2, interp_values2 = interp(x2, y2, step=step, start=start,
-                                stop=stop)
-    elif method == 'bin':
-        xi1, interp_values1, _ , _ = bin(x1, y1, bin_size=step, start=start,
-                                stop=stop)
-        xi2, interp_values2, _ , _ = bin(x2, y2, bin_size=step, start=start,
-                                stop=stop)
-    elif method == None:
-        min_idx1 = np.where(x1>=start)[0][0]
-        min_idx2 = np.where(x2>=start)[0][0]
-        max_idx1 = np.where(x1<=stop)[0][-1]
-        max_idx2 = np.where(x2<=stop)[0][-1]
+#     if method == 'interpolation':
+#     # perform the interpolation
+#         xi1, interp_values1 = interp(x1, y1, step=step, start=start,
+#                                 stop=stop)
+#         xi2, interp_values2 = interp(x2, y2, step=step, start=start,
+#                                 stop=stop)
+#     elif method == 'bin':
+#         xi1, interp_values1, _ , _ = bin(x1, y1, bin_size=step, start=start,
+#                                 stop=stop)
+#         xi2, interp_values2, _ , _ = bin(x2, y2, bin_size=step, start=start,
+#                                 stop=stop)
+#     elif method == None:
+#         min_idx1 = np.where(x1>=start)[0][0]
+#         min_idx2 = np.where(x2>=start)[0][0]
+#         max_idx1 = np.where(x1<=stop)[0][-1]
+#         max_idx2 = np.where(x2<=stop)[0][-1]
 
-        xi1 = x1[min_idx1:max_idx1+1]
-        xi2 = x2[min_idx2:max_idx2+1]
-        interp_values1 = y1[min_idx1:max_idx1+1]
-        interp_values2 = y2[min_idx2:max_idx2+1]
+#         xi1 = x1[min_idx1:max_idx1+1]
+#         xi2 = x2[min_idx2:max_idx2+1]
+#         interp_values1 = y1[min_idx1:max_idx1+1]
+#         interp_values2 = y2[min_idx2:max_idx2+1]
 
-    else:
-        raise KeyError('Not a valid interpolation method')
+#     else:
+#         raise KeyError('Not a valid interpolation method')
 
-    return xi1, xi2, interp_values1, interp_values2
+#     return xi1, xi2, interp_values1, interp_values2
 
 
 def standardize(x, scale=1, axis=0, ddof=0, eps=1e-3):
